#
# spec file for package f3
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           f3
Version:        9.0
Release:        1.1
Summary:        Fight Flash Fraud / Fight Fake Flash
License:        GPL-3.0-only
Group:          Hardware/Other
URL:            http://oss.digirati.com.br/f3/
Source:         https://github.com/AltraMayor/f3/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libparted)
BuildRequires:  pkgconfig(libudev)

%description
This package contains tools for identifying fake flash drives (primarily USB
sticks and memory cards).

A fake flash drive fraudulently inflates its apparent storage capacity (far)
beyond the physical capacity of its flash memory. Not surprisingly, using such
a flash drive will, sooner or later, result in data loss and/or corruption.

The main tools in this package are an open-source implementation of the H2testw
algorithm. Some extra tools are also provided, among them one for using
the actual storage capacity of fake drives as safely as possible.

%prep
%setup -q

%build
# workaround for libargp problem. see:
# https://github.com/AltraMayor/f3/issues/34#issuecomment-168775122
%if %{?suse_version} < 1500
export CFLAGS="%{optflags} -fgnu89-inline"
%else
export CFLAGS="%{optflags}"
%endif
%make_build all extra

mkdir examples
mv log-f3wr f3write.h2w examples
chmod a-x examples/*

%install
%make_install PREFIX=%{_prefix} install-extra

%files
%doc changelog README.rst examples
%license LICENSE
%{_bindir}/f3read
%{_bindir}/f3write
%{_bindir}/f3probe
%{_bindir}/f3brew
%{_bindir}/f3fix
%{_mandir}/man1/f3read.1%{?ext_man}
%{_mandir}/man1/f3write.1%{?ext_man}

%changelog
* Thu Mar 27 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to version 9.0:
  * f3read/f3write: Avoid the execution stack to list files
  * f3read/f3write: Add dynamic buffers
  * f3read/f3write: chroot(2) to source/target dir if allowed
  * Portability improvements for Ubuntu, ARM, OpenBSD, and Apple
  * Automated test of the code with GitHub Actions
  * Improved documentation
* Wed Nov 18 2020 Olav Reinert <seroton10@gmail.com>
- Upgrade to version 8.0:
  * f3read: add parameter --max-read-rate
  * f3read: report speed, percentage, remaining time like f3write
  * f3write: improve speed measurement (commit 791acdc32627...)
  * f3probe: handle rare assetion failure (issue #82 ENODATA)
* Wed May 20 2020 Olav Reinert <seroton10@gmail.com>
- update to 7.2:
  * f3write: keep up with extremely fast NVM drives (issue #117)
  * f3write: improve measurement of write speed (issue #102)
  * f3write: handle rare assetion failure (issue #111)
  * f3probe: handle rare assetion failure (issue #82)
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libudev) instead of libudev-devel: allow
  OBS to shortcut through the -mini flavors.
* Thu Jan 17 2019 t.gruner@katodev.de
- update to 7.1:
  * fix compilation issues on non-Linux OSs
  * f3write: make parameter --max-write-rate work precisely
  * f3probe: change default reset type to RT_NONE
- remove remove-ownership-setting.patch (accepted upstream, pull request #75)
* Wed Feb  7 2018 seroton10@gmail.com
- Fix build for Leap 42.2 and SLE12.
* Sat Feb  3 2018 avindra@opensuse.org
- update to 7.0:
  * stable version of f3probe, f3fix, and f3brew
  * f3write: improved write speed and dealing with write failures
- cleanup with spec-cleaner
- add remove-ownership-setting.patch
* Thu Feb 16 2017 t.gruner@katodev.de
- update to the latest commit 53772d3
- remove man-www-ref.patch
* Fri Jan 22 2016 seroton10@gmail.com
- Added man-www-ref.patch (accepted upstream, commit cbe8d61)
* Tue Jan 19 2016 seroton10@gmail.com
- Initial package of f3 version 6.0
